==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-slovenian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Vse teme");
define("_NOCOMMENTS","Brez komentarja");
define("_UCOMMENT","Komentar");
define("_REVIEWS","Recenzije");
define("_SEARCHUSERS","Ii v bazi podatkov uporabnikov");
define("_SEARCHSECTIONS","Ii v posebnih oddelkih");
define("_SEARCHREVIEWS","Ii v recenzijah");
define("_SEARCHIN","Ii v");
define("_ARTICLES","lankih");
define("_ALLAUTHORS","Vsi avtorji");
define("_ALL","Vsi");
define("_WEEK","teden");
define("_WEEKS","tednov");
define("_MONTH","mesec");
define("_MONTHS","mesecev");
define("_SEARCHON","Ii na:");
define("_SSTORIES","lanki");
define("_SSECTIONS","Oddelki");
define("_SUSERS","Uporabniki");
define("_NOMATCHES","Noben rezultat, ki bi odgovarjal vaemu iskanju ni bil najden");
define("_PREVMATCHES","prejnji rezultati");
define("_NEXTMATCHES","naslednji rezultati");
define("_INSECTION","lanek v oddelku");
define("_NONAME","Ime ni vneeno");
define("_SCOMMENTS","Komentarji");
define("_SEARCHRESULTS","Rezultati iskanja");
define("_CONTRIBUTEDBY","Poslal");
define("_UCOMMENTS","Komentarji");
define("_MATCHTITLE","Odgovarja naslovu");
define("_MATCHTEXT","Odgovarja tekstu lanka");
define("_MATCHBOTH","Odgovara naslovu in tekstu lanka");
define("_SREPLY","Odgovor");
define("_SREPLIES","Odgovori");
define("_ATTACHART","Dodano lanku");
define("_PAGES","Strani");
define("_REVIEWSCORE","Ocena te recenzije");
define("_PAGE","Strani");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-slovenian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Vse teme");
define("_NOCOMMENTS","Brez komentarja");
define("_UCOMMENT","Komentar");
define("_REVIEWS","Recenzije");
define("_SEARCHUSERS","Ii v bazi podatkov uporabnikov");
define("_SEARCHSECTIONS","Ii v posebnih oddelkih");
define("_SEARCHREVIEWS","Ii v recenzijah");
define("_SEARCHIN","Ii v");
define("_ARTICLES","lankih");
define("_ALLAUTHORS","Vsi avtorji");
define("_ALL","Vsi");
define("_WEEK","teden");
define("_WEEKS","tednov");
define("_MONTH","mesec");
define("_MONTHS","mesecev");
define("_SEARCHON","Ii na:");
define("_SSTORIES","lanki");
define("_SSECTIONS","Oddelki");
define("_SUSERS","Uporabniki");
define("_NOMATCHES","Noben rezultat, ki bi odgovarjal vaemu iskanju ni bil najden");
define("_PREVMATCHES","prejnji rezultati");
define("_NEXTMATCHES","naslednji rezultati");
define("_INSECTION","lanek v oddelku");
define("_NONAME","Ime ni vneeno");
define("_SCOMMENTS","Komentarji");
define("_SEARCHRESULTS","Rezultati iskanja");
define("_CONTRIBUTEDBY","Poslal");
define("_UCOMMENTS","Komentarji");
define("_MATCHTITLE","Odgovarja naslovu");
define("_MATCHTEXT","Odgovarja tekstu lanka");
define("_MATCHBOTH","Odgovara naslovu in tekstu lanka");
define("_SREPLY","Odgovor");
define("_SREPLIES","Odgovori");
define("_ATTACHART","Dodano lanku");
define("_PAGES","Strani");
define("_REVIEWSCORE","Ocena te recenzije");
define("_PAGE","Strani");

?>
